"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
log = logging.getLogger(__name__)


@register_command(
    extending=("notifications", "v2", "transaction"),
    module=argus_cli_module
)
def prepare_notification_transaction(
    recipients: dict = None,
    objectCustomer: str = None,
    objectID: str = None,
    service: str = None,
    operation: str = None,
    requestContext: dict = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Prepare a new notification transaction. This endpoint is NOT meant for users, only for applications on behalf of a user. (DEV)
    
    :param list recipients: List of user and email recipients to notify.
    :param str objectCustomer: Id or shortname for customer of the object this notification is related to.If notification is not customer relevant\, this may not be set.
    :param str objectID: Which Argus object \(case\, document\, sensor\, asset\, etc.\) generated the notification. Is not required\, as some operations will not have a corresponding Argus object.
    :param str service: What service generated the notification.
    :param str operation: What operation generated the notification.
    :param dict requestContext: 
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/notifications/v2/transaction".format()
    headers = {}

    body = body or {}
    # Only send recipients if the argument was provided, don't send null values
    if recipients is not None:
        body.update({"recipients": recipients})
    # Only send objectCustomer if the argument was provided, don't send null values
    if objectCustomer is not None:
        body.update({"objectCustomer": objectCustomer})
    # Only send objectID if the argument was provided, don't send null values
    if objectID is not None:
        body.update({"objectID": objectID})
    # Only send service if the argument was provided, don't send null values
    if service is not None:
        body.update({"service": service})
    # Only send operation if the argument was provided, don't send null values
    if operation is not None:
        body.update({"operation": operation})
    # Only send requestContext if the argument was provided, don't send null values
    if requestContext is not None:
        body.update({"requestContext": requestContext})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
